==> nextcloud-15.0.10.tar.bz2: nextcloud/apps/updatenotification/l10n/bg.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} е налична. Намерете допълнителна информация за това как да актуализирате.",
    "Update notifications" : "Известия за актуализации",
    "Channel updated" : "Канала е променен",
    "The update server could not be reached since %d days to check for new updates." : "Няма връзка със сървъра за актуализации от %d дни.",
    "Please check the Nextcloud and server log files for errors." : "Проверете журналите на Nextcloud и на сървъра за грешки.",
    "Update to %1$s is available." : "Налична е актуализация до версия %1$s.",
    "Update for %1$s to version %2$s is available." : "Налична е актуализация от %1$s до версия %2$s.",
    "Update for {app} to version %s is available." : "Обновление за {app} до версия %s е налично.",
    "Update notification" : "Известие за актуализация",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Инсталираната версия вече не се поддържа. Моля актуализирайте до поддържана версия възможно най-скоро.",
    "Apps missing updates" : "Приложения без актуализация",
    "View in store" : "Преглед в магазина",
    "Apps with available updates" : "Приложенията, с налични актуализации",
    "Open updater" : "Отвори актуализиращата програма",
    "Download now" : "Свали сега",
    "What's new?" : "Какви са промените?",
    "The update check is not yet finished. Please refresh the page." : "Проверката за актуализации не е приключила. Заредете страницата отново.",
    "Your version is up to date." : "Ползвате последната версия.",
    "A non-default update server is in use to be checked for updates:" : "Проверката за налични актуализации се извършва чрез сървър, който е различен от стандартния:",
    "Update channel:" : "Канал за актуализиране:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Винаги може да актуализирате до по-нова версия. Но не може да се върнете до по-стабилна (по-стара) версия.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "След издаването на нова версия обикновено няма да получите веднага известие. Потребителите се известяват на интервали, което може да доведе до пропускане на версия ако се появят проблеми.",
    "Notify members of the following groups about available updates:" : "Известявай следните групи при наличие на актуализация:",
    "Only notification for app updates are available." : "Налични са само известия за актуализации на приложенията.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Избрания канал за актуализации прави известията за този сървър остарели.",
    "The selected update channel does not support updates of the server." : "Избрания канал за актуализации не поддържа сървърни актуализации.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Налична е нова версия: <strong>{newVersionString}</strong>",
    "Checking apps for compatible updates" : "Проверка на приложенията за съвместими актуализации",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Свързването с магазина за приложения не е възможно или няма актуализации. Потърсете ръчно за актуализации или се уверете, че сървъра има връзка с Интернет и може да се свързва с магазина за приложения.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Всички</strong> приложения имат актуализация за наличната версия",
    "View changelog" : "Преглед на списъка с промени",
    "Stable" : "Стабилна",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Последната стабилна версия. Подходяща е за ежедневно ползване и се актуализации до последната главна версия.",
    "Production" : "Производствена ",
    "Will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2) and only if the instance is already on the latest minor version." : "Осигурява последните пачове, но не се актуализиране, веднага, до следваща главна версия. Актуализирането става на втората малка версия (x0.2), само при условие, че е инсталирана последната малка версия.",
    "Beta" : "Бета",
    "A pre-release version only for testing new features, not for production environments." : "Версия само за тестване на нови функционалности, която не е подходяща за ползване в производствена среда.",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> приложение няма актуализация за тази версия","<strong>%n</strong> приложения нямат актуализация за тази версия"],
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Винаги може да актуализирате до по-нова версия / експериментален канал. Но не можете да се върнете до по-стабилен канал.",
    "<strong>production</strong> will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2)." : "<strong>производствена</strong> осигурява последните пачове, но не се актуализира, веднага, до последната главна версия. Актуализацията става на втората малка версия (х.0.2).",
    "<strong>stable</strong> is the most recent stable version. It is suited for regular use and will always update to the latest major version." : "<strong>стабилна</strong> е последната стабилна версия. Подходяща е за ежедневно ползване и се актуализации до последната главна версия.",
    "<strong>beta</strong> is a pre-release version only for testing new features, not for production environments." : "<strong>бета</strong> е за тестване на нови функционалности. Не е подходяща за ползване в производствена среда.",
    "Could not start updater, please try the manual update" : "Актуализиращата програма не беше стартирана. Моля, опитайте ръчно обновление"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.11.tar.bz2: nextcloud/apps/updatenotification/l10n/bg.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} е налична. Намерете допълнителна информация за това как да актуализирате.",
    "Channel updated" : "Канала е променен",
    "Update notifications" : "Известия за актуализации",
    "The update server could not be reached since %d days to check for new updates." : "Няма връзка със сървъра за актуализации от %d дни.",
    "Please check the Nextcloud and server log files for errors." : "Проверете журналите на Nextcloud и на сървъра за грешки.",
    "Update to %1$s is available." : "Налична е актуализация до версия %1$s.",
    "Update for %1$s to version %2$s is available." : "Налична е актуализация от %1$s до версия %2$s.",
    "Update for {app} to version %s is available." : "Обновление за {app} до версия %s е налично.",
    "Update notification" : "Известие за актуализация",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Инсталираната версия вече не се поддържа. Моля актуализирайте до поддържана версия възможно най-скоро.",
    "Apps missing updates" : "Приложения без актуализация",
    "View in store" : "Преглед в магазина",
    "Apps with available updates" : "Приложенията, с налични актуализации",
    "Open updater" : "Отвори актуализиращата програма",
    "Download now" : "Свали сега",
    "What's new?" : "Какви са промените?",
    "The update check is not yet finished. Please refresh the page." : "Проверката за актуализации не е приключила. Заредете страницата отново.",
    "Your version is up to date." : "Ползвате последната версия.",
    "A non-default update server is in use to be checked for updates:" : "Проверката за налични актуализации се извършва чрез сървър, който е различен от стандартния:",
    "Update channel:" : "Канал за актуализиране:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Винаги може да актуализирате до по-нова версия. Но не може да се върнете до по-стабилна (по-стара) версия.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "След издаването на нова версия обикновено няма да получите веднага известие. Потребителите се известяват на интервали, което може да доведе до пропускане на версия ако се появят проблеми.",
    "Notify members of the following groups about available updates:" : "Известявай следните групи при наличие на актуализация:",
    "Only notification for app updates are available." : "Налични са само известия за актуализации на приложенията.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Избрания канал за актуализации прави известията за този сървър остарели.",
    "The selected update channel does not support updates of the server." : "Избрания канал за актуализации не поддържа сървърни актуализации.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Налична е нова версия: <strong>{newVersionString}</strong>",
    "Checking apps for compatible updates" : "Проверка на приложенията за съвместими актуализации",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Свързването с магазина за приложения не е възможно или няма актуализации. Потърсете ръчно за актуализации или се уверете, че сървъра има връзка с Интернет и може да се свързва с магазина за приложения.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Всички</strong> приложения имат актуализация за наличната версия",
    "View changelog" : "Преглед на списъка с промени",
    "Stable" : "Стабилна",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Последната стабилна версия. Подходяща е за ежедневно ползване и се актуализации до последната главна версия.",
    "Beta" : "Бета",
    "A pre-release version only for testing new features, not for production environments." : "Версия само за тестване на нови функционалности, която не е подходяща за ползване в производствена среда.",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> приложение няма актуализация за тази версия","<strong>%n</strong> приложения нямат актуализация за тази версия"],
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Винаги може да актуализирате до по-нова версия / експериментален канал. Но не можете да се върнете до по-стабилен канал.",
    "<strong>production</strong> will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2)." : "<strong>производствена</strong> осигурява последните пачове, но не се актуализира, веднага, до последната главна версия. Актуализацията става на втората малка версия (х.0.2).",
    "<strong>stable</strong> is the most recent stable version. It is suited for regular use and will always update to the latest major version." : "<strong>стабилна</strong> е последната стабилна версия. Подходяща е за ежедневно ползване и се актуализации до последната главна версия.",
    "<strong>beta</strong> is a pre-release version only for testing new features, not for production environments." : "<strong>бета</strong> е за тестване на нови функционалности. Не е подходяща за ползване в производствена среда.",
    "Could not start updater, please try the manual update" : "Актуализиращата програма не беше стартирана. Моля, опитайте ръчно обновление",
    "Production" : "Производствена ",
    "Will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2) and only if the instance is already on the latest minor version." : "Осигурява последните пачове, но не се актуализиране, веднага, до следваща главна версия. Актуализирането става на втората малка версия (x0.2), само при условие, че е инсталирана последната малка версия."
},
"nplurals=2; plural=(n != 1);");
